Welcome to Freezer Agent Release Notes documentation!
=====================================================

Contents
========

.. toctree::
   :maxdepth: 2

   unreleased
   newton

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`